#include "bits/stdc++.h"

#define pb push_back
#define len(v) ((int)v.size())
#define mp make_pair
#define mt make_tuple
#define x first
#define y second

using namespace std;

typedef long long ll;
typedef pair<int, int> pii;
typedef long double ld;

template<class T>
ostream &operator<<(ostream &os, const vector<T> &v) {
	for (const T &x : v) {
		os << x << " ";
	}
	return os;
}

template<class T>
istream &operator>>(istream &is, vector<T> &v) {
	for (T &x : v) {
		is >> x;
	}
	return is;
}

template<class A, class B>
ostream &operator<<(ostream &os, const pair<A, B> &p) {
	os << p.x << " " << p.y;
	return os;
}

template<class A, class B>
istream &operator>>(istream &is, pair<A, B> &p) {
	is >> p.x >> p.y;
	return is;
}


void run();

signed main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);
	run();
}

int all = 0;
vector<int> F, S;

struct Flow {
	struct Edge;
	vector<vector<Edge>> g;
	vector<bool> alive;
	struct Edge {
		int flow = 0;
		int lim = 0;
		int to;
		int pair_id;

		Edge() {}

		Edge(int _to, int _lim, int _pair_id) {
			to = _to;
			lim = _lim;
			pair_id = _pair_id;
		}

		int max_push() {
			return lim - flow;
		}
	};

	void push(Edge &edge, int x) {
		edge.flow += x;
		g[edge.to][edge.pair_id].flow -= x;
	}

	int st, end;

	void add_edge(int a, int b, int lim) {
		g[a].emplace_back(b, lim, len(g[b]));
		g[b].emplace_back(a, 0, len(g[a]) - 1);
	}

	Flow(int n, int _st, int _end) {
		g.resize(n);
		alive.resize(n, true);
		st = _st;
		end = _end;
	}

	vector<int> dist;
	vector<int> iter;

	int dfs(int v, int _min) {
		if (v == end) return _min;
		for (; iter[v] < len(g[v]); iter[v]++) {
			Edge &e = g[v][iter[v]];
			if (alive[e.to] && e.max_push() && dist[e.to] == dist[v] + 1) {
				int t = dfs(e.to, min(_min, e.max_push()));
				if (t) {
					push(e, t);
					return t;
				}
			}
		}
		return 0;
	}

	int bfs() {
		dist = vector<int>(len(g), 1e9);
		dist[st] = 0;
		deque<int> deq{st};
		while (!deq.empty()) {
			int v = deq[0];
			deq.pop_front();
			for (Edge e : g[v]) {
				if (!alive[e.to]) continue;
				if (e.max_push() == 0) continue;
				if (dist[e.to] > dist[v] + 1) {
					dist[e.to] = dist[v] + 1;
					deq.pb(e.to);
				}
			}
		}
		return dist[end] != 1e9;
	}

	int max_flow() {
		while (bfs()) {
			iter = vector<int>(len(g));
			while (dfs(st, 1e9)) {
			}
		}
		
		int rez = 0;
		for (Edge e : g[st]) {
			rez += e.flow;
		}
		return rez;
	}
	
	void remove(int x) {
		if (!alive[x]) return;
		for (int i = 0; i < len(g); i++) {
			for (Edge &e : g[i]) {
				e.flow = 0;
			}
		}
		alive[x] = false;
		all -= F[x] + S[x];
	}

	void clear_all() {
		for (int i = 0; i < len(g); i++) {
			for (Edge &e : g[i]) {
				e.flow = 0;
			}
		}
	}

	void add(int x) {
		if (alive[x]) return;
		alive[x] = true;
		all += F[x] + S[x];
	}
};

int n, m;

void run() {
	cin >> n >> m;
	Flow flow(n + 2, n, n + 1);	
	F.resize(n);
	S.resize(n);
	cin >> F >> S;
	for (int i = 0; i < m; i++) {
		int a, b, w;
		cin >> a >> b >> w;
		a--;b--;
		flow.add_edge(a, b, w);
		flow.add_edge(b, a, w);
		// all += w;
	}
	for (int x : F) {
		all += x;
	}	
	for (int x : S) {
		all += x;
	}
	// cout << all << endl;

	for (int i = 0; i < n; i++) {
		flow.add_edge(n, i, F[i]);
		flow.add_edge(i, n + 1, S[i]);
	}
	// cout << flow.max_flow() << endl;
	cout << all - flow.max_flow() << endl;

	int q;	
	cin >> q;
	vector<pii> qs;
	vector<int> final;
	auto answer = [&flow, &qs, &final]() {
		flow.clear_all();
		for (int i = 0; i < n; i++) {
			flow.add(i);
		}

		for (pii p : qs) {
			if (p.first == 2) {
				flow.remove(p.second);
			}	
			if (p.first == 4) {
				for (int i = 0; i < n / 5; i++) {
					flow.remove(i);
				}
			}
		}
		reverse(qs.begin(), qs.end());
		vector<int> cur;
		for (pii p : qs) {
			if (p.first == 2) {
				cur.pb(all - flow.max_flow());
				flow.add(p.second);
			}
			if (p.first == 4) {
				for (int i = 0; i < n / 5; i++) {
					flow.add(i);
				}
			}
		}
		reverse(cur.begin(), cur.end());
		for (int x : cur) {
			final.pb(x);
		}
		qs.clear();
	};
	for (int i = 0; i < q; i++) {
		int t;
		cin >> t;
		if (t == 3) {
			answer();
			continue;
		}
		if (t == 1) {
			int v;	
			cin >> v;
			v--;
			qs.emplace_back(t, v);
			// flow.add(v);
			// cout << all - flow.max_flow() << "\n";
		} else if (t == 2) {
			int v;
			cin >> v;
			v--;
			qs.emplace_back(t, v);
			// flow.remove(v);
			// cout << all - flow.max_flow() << "\n";
		} else if (t == 3) {
			// for (int i = 0; i < n; i++) {
				// flow.add(i);
			// }
			qs.emplace_back(t, -1);
		} else if (t == 4) {
			// for (int i = 0; i < n / 5; i++) {
				// flow.remove(i);
			// }
			qs.emplace_back(t, -1);
		}
	}
	for (int x : final) {
		cout << x << "\n";
	}
}