#include <iostream>
#include <fstream>
#include <vector>
#include <set>
#include <map>
#include <bitset>
#include <algorithm>
#include <iomanip>
#include <string>
#include <cstring>
#include <iomanip>
#include <functional>
#include <numeric>
#include <random>
#include <queue>
#define ll long long
#define ld long double
#define null NULL
#define all(a) a.begin(), a.end()

using namespace std;

template<class iterator> void output(iterator begin, iterator end, ostream &out = cerr) {
	while (begin != end) {
		out << (*begin) << " ";
		begin++;
	}
	out << endl;
}

template<class T> void output(T x, ostream &out = cerr) {
	output(x.begin(), x.end(), out);
}

template<class T> int chkmin(T &a, const T &b) {
	if (b < a) {
		a = b;
		return 1;
	}
	return 0;
}

template<class T> int chkmax(T &a, const T &b) {
	if (b > a) {
		a = b;
		return 1;
	}
	return 0;
}

void fast_io() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);
}

const int INF = 1e9;

struct dinic {
	struct edge {
		int u, v, cap, flow;
	};

	vector<edge> e;
	vector<vector<int> > g;
	vector<int> ptr, d;
	int n, s, t, step;

	dinic() {}

	void init(int _n, int _s, int _t) {
		n = _n;
		s = _s;
		t = _t;
		g.resize(n);
		ptr.resize(n);
		d.resize(n);
	}

	void add_edge(int u, int v, int cap, int back_cap) {
		//cerr << "add_edge " << u << " " << v << " " << cap << " " << back_cap << endl;
		g[u].push_back(e.size());
		e.push_back({u, v, cap, 0});
		g[v].push_back(e.size());
		e.push_back({v, u, back_cap, 0});
	}

	int bfs() {
		for (int i = 0; i < n; ++i) {
			d[i] = INF;
		}

		queue<int> q;
		d[s] = 0;
		q.push(s);
		while (!q.empty()) {
			int v = q.front();
			q.pop();
			for (auto en : g[v]) {
				int v1 = e[en].v;
				if (e[en].cap - e[en].flow >= step && d[v1] == INF) {
					d[v1] = d[v] + 1;
					q.push(v1);
				}
			}
		}

		if (d[t] == INF) {
			return 0;
		}
		else {
			return 1;
		}
	}

	int dfs(int v, int to_push) {
		if (v == t) {
			return to_push;
		}

		while (ptr[v] < g[v].size()) {
			int en = g[v][ptr[v]], v1 = e[en].v, diff = e[en].cap - e[en].flow;
			if (diff >= step && d[v1] == d[v] + 1) {
				int pushed = dfs(v1, min(to_push, diff));
				if (pushed) {
					e[en].flow += pushed;
					e[en ^ 1].flow -= pushed;
					return pushed;
				}
			}
			ptr[v]++;
		}

		return 0;
	}

	int solve() {
		int ans = 0;
		for (step = (1 << 9); step >= 1; step /= 2) {
			while (bfs()) {
				for (int i = 0; i < n; ++i) {
					ptr[i] = 0;
				}
				while (true) {
					int res = dfs(s, INF);
					if (res) {
						ans += res;
					}
					else {
						break;
					}
				}
			}
		}
		return ans;
	}
};

struct edge2 {
	int u, v, cost;
};

const int mx = 1e3 + 10;
int n, m, a[mx], b[mx], have[mx];
vector<edge2> e;

int get() {
	int res = 0;
	dinic solver;
	solver.init(n + 2, n, n + 1);
	
	for (int i = 0; i < n; ++i) {
		if (have[i]) {
			solver.add_edge(n, i, a[i], 0);
			solver.add_edge(i, n + 1, b[i], 0);
			res += (a[i] + b[i]);
		}
	}

	for (auto ed : e) {
		int u = ed.u, v = ed.v, cost = ed.cost;
		if (have[u] && have[v]) {
			solver.add_edge(u, v, cost, cost);
		}
	}

	res -= solver.solve();
	return res;
}

signed main() {
	cin >> n >> m;
	for (int i = 0; i < n; ++i) {
		cin >> a[i];
		have[i] = 1;
	}
	for (int i = 0; i < n; ++i) {
		cin >> b[i];
	}
	for (int i = 0; i < m; ++i) {
		int u, v, cost;
		cin >> u >> v >> cost;
		u--;
		v--;
		e.push_back({u, v, cost});
	}

	cout << get() << endl;

	int q;
	cin >> q;
	for (int i = 0; i < q; ++i) {
		int type;
		cin >> type;
		if (type == 1) {
			int pos;
			cin >> pos;
			pos--;
			have[pos] = 1;
			cout << get() << endl;
		}
		if (type == 2) {
			int pos;
			cin >> pos;
			pos--;
			have[pos] = 0;
			cout << get() << endl;
		}
		if (type == 3) {
			for (int j = 0; j < n; ++j) {
				have[j] = 1;
			}
		}
		if (type == 4) {
			for (int j = 1; j <= n / 5; ++j) {
				int pos = j - 1;
				have[pos] = 0;
			}
		}
	}
}
